colour.notation.dataset Package — Colour 0.3.0 documentation

# colour.notation.dataset Package

## Sub-Packages

- colour.notation.dataset.munsell Package
  - Sub-Modules
    - colour.notation.dataset.munsell.all Module
      - Munsell Renotation System Dataset - All Munsell Colours
    - colour.notation.dataset.munsell.experimental Module
      - Munsell Renotation System Dataset - 1929 Munsell Colours
    - colour.notation.dataset.munsell.real Module
      - Munsell Renotation System Dataset - Real Munsell Colours
  - Module Contents

## Module Contents